
# Slot: has quotient




URI: [biolink:has_quotient](https://w3id.org/biolink/vocab/has_quotient)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..1</sub> [Double](types/Double.md)

## Parents

 *  is_a: [aggregate statistic](aggregate_statistic.md)

## Children

 *  [variant to population association➞has quotient](variant_to_population_association_has_quotient.md)

## Used by

 * [FrequencyQuantifier](FrequencyQuantifier.md)
